from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import Literal, cast






T = TypeVar("T", bound="ConnectionClosedMessage")



@_attrs_define
class ConnectionClosedMessage:
    """ Sent when connection is closed (e.g., another tab opened).

        Attributes:
            message (str):
            type_ (Literal['connection_closed'] | Unset):  Default: 'connection_closed'.
     """

    message: str
    type_: Literal['connection_closed'] | Unset = 'connection_closed'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        message = self.message

        type_ = self.type_


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "message": message,
        })
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        message = d.pop("message")

        type_ = cast(Literal['connection_closed'] | Unset , d.pop("type", UNSET))
        if type_ != 'connection_closed'and not isinstance(type_, Unset):
            raise ValueError(f"type must match const 'connection_closed', got '{type_}'")

        connection_closed_message = cls(
            message=message,
            type_=type_,
        )


        connection_closed_message.additional_properties = d
        return connection_closed_message

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
